@@ -17,6 +17,9 @@ mpl.rcParams['figure.subplot.left']   = 0.05
 mpl.rcParams['figure.subplot.bottom'] = 0.05
 mpl.rcParams['figure.subplot.right']  = 0.95
 mpl.rcParams['figure.subplot.top']    = 0.90
+mpl.rcParams['font.family'] = 'sans-serif'
+mpl.rcParams['mathtext.fontset'] = 'stixsans'
+mpl.rcParams['mathtext.default'] = 'regular'
 
 #--------------------------------------------------------------------
 # Define transformation matricies
@@ -47,10 +50,11 @@ def _merge_elements( elm_def ):
         base_elm = elm_def['base']
         elm_def.pop('base')
 
-        elm_def['paths']  = elm_def.get('paths',[] ) + base_elm.get( 'paths',  [] )
-        elm_def['labels'] = elm_def.get('labels',[]) + base_elm.get( 'labels', [] )
-        elm_def['shapes'] = elm_def.get('shapes',[]) + base_elm.get( 'shapes', [] )
-
+        elm_def['paths']   = elm_def.get('paths',[] ) + base_elm.get( 'paths',  [] )
+        elm_def['labels']  = elm_def.get('labels',[]) + base_elm.get( 'labels', [] )
+        elm_def['shapes']  = elm_def.get('shapes',[]) + base_elm.get( 'shapes', [] )
+        elm_def['anchors'] = dict(list(elm_def.get('anchors',{}).items()) + list(base_elm.get( 'anchors', {} ).items()))
+        
         for i in base_elm:
             # Everything that's not a list. New key/values overwrite old.
             # If base has a base, will be added and loop will pick it up.
@@ -63,7 +67,7 @@ def _merge_elements( elm_def ):
 # Main drawing class
 #--------------------------------------------------------------------
 class Drawing():
-    def __init__(self, unit=3.0, inches_per_unit=0.5, txtofst=0.1, fontsize=16, font='sans-serif'):
+    def __init__(self, unit=3.0, inches_per_unit=0.5, txtofst=0.1, fontsize=16, font='sans-serif', color='black'):
         """ Set up a new circuit drawing.
     unit : Full length of a resistor element in matplotlib plot units.
            Inner portion of resistor is length 1.
@@ -79,6 +83,7 @@ class Drawing():
         self.txtofst = txtofst
         self.fontsize = fontsize
         self.font = font
+        self.color = color
 
         # State variables
         self.here = np.array([0,0])
@@ -185,12 +190,12 @@ Other:
 
 
 
-    def save(self, fname, transparent=False ):
+    def save(self, fname, transparent=True, dpi=72 ):
         """ Save figure to file.
             fname : filename to save.
                     File type automatically determined from extension.
         """
-        self.fig.savefig( fname, bbox_extra_artists=self.ax.get_default_bbox_extra_artists(), bbox_inches='tight', transparent=transparent )
+        self.fig.savefig( fname, bbox_extra_artists=self.ax.get_default_bbox_extra_artists(), bbox_inches='tight', transparent=transparent, dpi=dpi )
 
 
     # Functions to help define specific elements
@@ -309,7 +314,7 @@ Other:
 
         # Get some parameters
         self.shapes = self.defn.get( 'shapes', [] )
-        self.color  = kwargs.get( 'color', self.defn.get('color', 'black' ) )
+        self.color  = kwargs.get( 'color', self.defn.get('color', drawing.color ) )
         totlen      = kwargs.get( 'l', drawing.unit   )
 
         # Determine theta angle of element
@@ -647,9 +652,9 @@ Other:
             if s.get('shape') == 'circle':
                 xy = np.array(s.get('center', [0,0]))
                 xy = self.translate( xy - self.ofst)
-                rad  = s.get('radius', 1)
+                rad  = s.get('radius', 1) * self.z
                 fill = s.get('fill', False)
-                fillcolor = s.get('fillcolor', 'black')
+                fillcolor = s.get('fillcolor', self.color)
                 circ = plt.Circle( xy=xy, radius=rad, ec=self.color,
                                    fc=fillcolor, fill=fill, zorder=3 )
                 ax.add_patch(circ)
@@ -658,17 +663,20 @@ Other:
                 xy = self.translate( xy - self.ofst )
                 closed = s.get('closed', True)
                 fill = s.get('fill', False)
-                fillcolor = s.get('fillcolor', 'black')
+                fillcolor = s.get('fillcolor', self.color)
                 poly = plt.Polygon( xy=xy, closed=closed, ec=self.color,
                                     fc=fillcolor, fill=fill, zorder=3 )
                 ax.add_patch(poly)
             elif s.get('shape') == 'arc':
                 xy = np.array(s.get('center', [0,0] ) )
                 xy = self.translate( xy - self.ofst )
-                w = s.get('width',     1  )
-                h = s.get('height',    1  )
+
+                w = s.get('width',     1  ) * self.z
+                h = s.get('height',    1  ) * self.z
                 th1 = s.get('theta1',  35 )
                 th2 = s.get('theta2', -35 )
+                if self.reverse: th1, th2 = th2, th1
+
                 angle = s.get('angle', self.theta )
                 arc = Arc( xy, width=w, height=h, theta1=th1,
                            theta2=th2, angle=angle, color=self.color )
@@ -697,7 +705,7 @@ Other:
                     darrow = np.dot( [dx,dy], m )
 
                     ax.arrow( s[0], s[1], darrow[0], darrow[1], head_width=.15,
-                              head_length=.25, color='black' )
+                              head_length=.25, color=self.color )
 
             elif s.get('shape') == 'arrow':
                 start = np.array(s.get('start', [0,0] ) )
